@@ -130,6 +130,10 @@ bool ClassifierCodeDocument::hasObjectVectorClassFields()
         if((*it)->getClassFieldType() != CodeClassField::Attribute)
         {
             UMLRole * role = dynamic_cast<UMLRole*>((*it)->getParentObject());
+            if (!role) {
+                uError() << "invalid parent object type";
+                return false;
+            }
             QString multi = role->multiplicity();
             if (
                 multi.contains(QRegExp(QLatin1String("[23456789\\*]"))) ||
@@ -300,6 +304,7 @@ void ClassifierCodeDocument::addOperation (UMLClassifierListItem * o)
     UMLOperation *op = dynamic_cast<UMLOperation*>(o);
     if (op == NULL) {
         uError() << "arg is not a UMLOperation";
+        return;
     }
     QString tag = CodeOperation::findTag(op);
     CodeOperation * codeOp = dynamic_cast<CodeOperation*>(findTextBlockByTag(tag, true));
