@@ -54,17 +54,11 @@ typedef QPair<UMLEntityAttribute*, UMLEntityAttribute*> EntityAttributePair;
  *  @param pForeignKeyConstraint The Unique Constraint to show the properties of
  */
 UMLForeignKeyConstraintDialog::UMLForeignKeyConstraintDialog(QWidget* parent, UMLForeignKeyConstraint* pForeignKeyConstraint)
-  : KPageDialog(parent),
+  : DialogBase(parent),
     m_doc(UMLApp::app()->document()),
     m_pForeignKeyConstraint(pForeignKeyConstraint)
 {
     setCaption(i18n("Foreign Key Setup"));
-    setButtons(Help | Ok | Apply | Cancel);
-    setDefaultButton(Ok);
-    setModal(true);
-    showButtonSeparator(true);
-    setFaceType(KPageDialog::List);
-
     setupGeneralPage();
     setupColumnPage();
 
@@ -215,7 +209,7 @@ void UMLForeignKeyConstraintDialog::setupGeneralPage()
     generalLayout->setSpacing(spacingHint());
     generalLayout->setMargin(fontMetrics().height());
 
-    Dialog_Utils::makeLabeledEditField(m_GeneralWidgets.generalGB, generalLayout, 0,
+    Dialog_Utils::makeLabeledEditField(generalLayout, 0,
                                        m_GeneralWidgets.nameL, i18nc("label for entering name", "Name"),
                                        m_GeneralWidgets.nameT);
 
